pycocoa.screens.DeepestScreen

Package pycocoa :: Module screens :: Class DeepestScreen |
[frames] | no frames]

# Class DeepestScreen

      object --+
               |
    bases._Type0 --+
                   |
              Screen --+
                       |
                      DeepestScreen

The Deepest screen, the one with most colors.

Instance Methods
Inherited from `Screen`: `__eq__`, `cascade` Inherited from `bases._Type0`: `__init__`, `__repr__`, `__str__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `Screen`: `__new__`

Properties
Inherited from `Screen`: `bottom`, `bottomleft`, `bottomright`, `center`, `colorSpace`, `deviceDescription`, `deviceDict`, `displayID`, `frame`, `isBuiltIn`, `isExternal`, `isPrinter`, `isScreen`, `left`, `name`, `named`, `origin`, `pixels`, `ratio`, `resolutions`, `right`, `size`, `top`, `topleft`, `topright`, `visibleFrame` Inherited from `bases._Type0`: `NS`, `NSDelegate` Inherited from `object`: `__class__`